@@ -727,15 +727,6 @@ static retvalue pull_search(/*@null@*/FILE *out,struct database *database,struct
 	retvalue result,r;
 	struct pull_target *u;
 
-	if( d->distribution->deb_override != NULL ||
-			d->distribution->dsc_override != NULL ||
-			d->distribution->udeb_override != NULL ) {
-		if( verbose >= 0 )
-			fprintf(stderr,
-"Warning: Override files of '%s' ignored as not yet supported while updating!\n",
-					d->distribution->codename);
-	}
-
 	result = RET_NOTHING;
 	for( u=d->targets ; u != NULL ; u=u->next ) {
 		r = pull_searchformissing(out, database, u);
@@ -911,6 +902,9 @@ retvalue pull_update(struct database *database, struct pull_distribution *distri
 		r = distribution_prepareforwriting(d->distribution);
 		if( RET_WAS_ERROR(r) )
 			return r;
+		r = distribution_loadalloverrides(d->distribution);
+		if( RET_WAS_ERROR(r) )
+			return r;
 	}
 
 	if( verbose >= 0 )
@@ -961,6 +955,12 @@ retvalue pull_checkupdate(struct database *database, struct pull_distribution *d
 	struct pull_distribution *d;
 	retvalue result,r;
 
+	for( d=distributions ; d != NULL ; d=d->next) {
+		r = distribution_loadalloverrides(d->distribution);
+		if( RET_WAS_ERROR(r) )
+			return r;
+	}
+
 	if( verbose >= 0 )
 		fprintf(stderr,"Calculating packages to get...\n");
 
@@ -981,6 +981,12 @@ retvalue pull_dumpupdate(struct database *database, struct pull_distribution *di
 	struct pull_distribution *d;
 	retvalue result,r;
 
+	for( d=distributions ; d != NULL ; d=d->next) {
+		r = distribution_loadalloverrides(d->distribution);
+		if( RET_WAS_ERROR(r) )
+			return r;
+	}
+
 	result = RET_NOTHING;
 
 	for( d=distributions ; d != NULL ; d=d->next) {
