@@ -23,7 +23,7 @@ struct remote_index;
 struct remote_repository *remote_repository_prepare(const char *name, const char *method, const char *fallback, const struct strlist *config);
 
 /* register remote distribution of the given repository */
-struct remote_distribution *remote_distribution_prepare(struct remote_repository *, const char *suite, bool ignorerelease, const char *verifyrelease, bool flat, bool *ignorehashes);
+retvalue remote_distribution_prepare(struct remote_repository *, const char *suite, bool ignorerelease, const char *verifyrelease, bool flat, bool *ignorehashes, /*@out@*/struct remote_distribution **out_p);
 
 void remote_repository_free(/*@only@*/struct remote_repository *);
 
