@@ -3,7 +3,9 @@
 
 enum term_comparison { tc_none=0, tc_equal, tc_strictless, tc_strictmore,
 				  tc_lessorequal, tc_moreorequal,
-				  tc_notequal};
+				  tc_notequal, tc_globmatch, tc_notglobmatch};
+
+struct term_special;
 
 typedef struct term_atom {
 	/* global list to allow freeing them all */
@@ -12,18 +14,36 @@ typedef struct term_atom {
 	 * nextiftrue  == NULL means total result is true,
 	 * nextiffalse == NULL means total result is false. */
 	/*@dependent@*/struct term_atom *nextiftrue,*nextiffalse;
-	bool negated;
-
-	/* package-name or key */
-	char *key;
-	/* version/value requirement */
-	enum term_comparison comparison;
-	char *comparewith;
+	bool negated, isspecial;
 	/* architecture requirements */
 	bool architectures_negated;
 	struct strlist architectures;
+	/* version/value requirement */
+	enum term_comparison comparison;
+	union {
+		struct {
+			/* package-name or key */
+			char *key;
+			/* version/value requirement */
+			char *comparewith;
+		} generic;
+		struct {
+			const struct term_special *type;
+			struct compare_with {
+				void *pointer;
+				long number;
+			} comparewith;
+		} special;
+	};
 } term;
 
+struct term_special {
+	const char *name;
+	retvalue (*parse)(enum term_comparison, const char *, size_t len, struct compare_with *);
+	bool (*compare)(enum term_comparison, const struct compare_with *, const void*, const void*);
+	void (*done)(enum term_comparison, struct compare_with *);
+};
+
 /* | is allowed in terms */
 #define T_OR		0x01
 /* () are allowed to build sub-expressions */
@@ -36,11 +56,10 @@ typedef struct term_atom {
 #define T_ARCHITECTURES 0x20
 /* (!= value) is allowed */
 #define T_NOTEQUAL	0x40
+/* (% <globpattern>) and (!% globpattern) are allowed */
+#define T_GLOBMATCH	0x80
 
-retvalue term_compile(/*@out@*/term **term, const char *formula, int options);
+retvalue term_compile(/*@out@*/term **term, const char *formula, int options, /*@null@*/const struct term_special *specials);
 void term_free(/*@null@*//*@only@*/term *term);
 
-/* decide based on a chunk, (warning: string comparisons even for version!)*/
-retvalue term_decidechunk(term *condition,const char *controlchunk);
-
 #endif
