@@ -1,5 +1,5 @@
 /*  This file is part of "reprepro"
- *  Copyright (C) 2005,2006,2007,2008 Bernhard R. Link
+ *  Copyright (C) 2005,2006,2007,2008,2009 Bernhard R. Link
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
  *  published by the Free Software Foundation.
@@ -332,7 +332,7 @@ static inline retvalue parse_data(const char *name, const char *version, const c
 	return RET_OK;
 }
 
-static retvalue tracking_get(trackingdb t,const char *sourcename,const char *version,/*@out@*/struct trackedpackage **pkg) {
+retvalue tracking_get(trackingdb t, const char *sourcename, const char *version, /*@out@*/struct trackedpackage **pkg) {
 	size_t versionlen;
 	const char *data;
 	size_t datalen;
@@ -746,6 +746,33 @@ retvalue trackingdata_new(trackingdb tracks,struct trackingdata *data) {
 	return RET_OK;
 }
 
+retvalue trackingdata_switch(struct trackingdata *data, const char *source, const char *version) {
+	retvalue r;
+
+	if( data->pkg != NULL ) {
+		if( strcmp(data->pkg->sourcename, source) == 0 &&
+				strcmp(data->pkg->sourceversion, version) == 0 )
+			return RET_OK;
+		r = tracking_saveonly(data->tracks, data->pkg);
+		if( RET_WAS_ERROR(r) )
+			return r;
+		r = trackingdata_remember(data, data->pkg->sourcename,
+				data->pkg->sourceversion);
+		strlist_done(&data->pkg->filekeys);
+		free(data->pkg->refcounts);
+		free(data->pkg->filetypes);
+		free(data->pkg);
+		data->pkg = NULL;
+		if( RET_WAS_ERROR(r) )
+			return r;
+	}
+	r = tracking_getornew(data->tracks, source, version, &data->pkg);
+	assert( r != RET_NOTHING );
+	if( RET_WAS_ERROR(r) )
+		return r;
+	return RET_OK;
+}
+
 retvalue trackingdata_insert(struct trackingdata *data,enum filetype filetype,const struct strlist *filekeys,/*@null@*//*@only@*/char*oldsource,/*@null@*//*@only@*/char*oldversion,/*@null@*/const struct strlist *oldfilekeys,struct database *database) {
 	retvalue result,r;
 	struct trackedpackage *pkg;
@@ -1093,6 +1120,7 @@ static retvalue targetremovesourcepackage(trackingdb t, struct trackedpackage *p
 		const char *s, *basefilename, *filekey = pkg->filekeys.values[i];
 		char *package, *control, *source, *version;
 		struct strlist filekeys;
+		bool savedstaletracking;
 
 		if( pkg->refcounts[i] <= 0 )
 			continue;
@@ -1210,10 +1238,16 @@ static retvalue targetremovesourcepackage(trackingdb t, struct trackedpackage *p
 			return r;
 		}
 
+		/* we remove the tracking data outself, so this is not
+		 * told to remove the tracking data, so it might mark things
+		 * as stale, which we do not want.. */
+		savedstaletracking = target->staletracking;
+
 		/* that is a bit wasteful, as it parses some stuff again, but
 		 * but that is better than reimplementing logger here */
 		r = target_removereadpackage(target, distribution->logger,
 				database, package, control, NULL);
+		target->staletracking = savedstaletracking;
 		free(control);
 		free(package);
 		assert( r != RET_NOTHING );
@@ -1289,3 +1323,53 @@ retvalue tracking_removepackages(trackingdb t, struct database *database, struct
 	}
 	return result;
 }
+
+static retvalue package_retrack(struct database *database, UNUSED(struct distribution *di), struct target *target, const char *packagename, const char *controlchunk, void *data) {
+	trackingdb tracks = data;
+
+	return target->doretrack(packagename, controlchunk,
+			tracks, database);
+}
+
+retvalue tracking_retrack(struct database *database, struct distribution *d, bool needsretrack) {
+	struct target *t;
+	trackingdb tracks;
+	retvalue r, rr;
+
+	if( d->tracking == dt_NONE )
+		return RET_NOTHING;
+
+	for( t = d->targets ; !needsretrack && t != NULL ; t = t->next ) {
+		if( t->staletracking )
+			needsretrack = true;
+	}
+	if( !needsretrack )
+		return RET_NOTHING;
+
+	if( verbose > 0 )
+		printf("Retracking %s...\n", d->codename);
+
+	r = tracking_initialize(&tracks, database, d, false);
+	if( !RET_IS_OK(r) )
+		return r;
+	/* first forget that any package is there*/
+	r = tracking_reset(tracks);
+	if( !RET_WAS_ERROR(r) ) {
+		/* add back information about actually used files */
+		r = distribution_foreach_package(d, database,
+				atom_unknown, atom_unknown, atom_unknown,
+				package_retrack, NULL, tracks);
+	}
+	if( RET_IS_OK(r) ) {
+		for( t = d->targets ; t != NULL ; t = t->next ) {
+			t->staletracking = false;
+		}
+	}
+	if( !RET_WAS_ERROR(r) ) {
+		/* now remove everything no longer needed */
+		r = tracking_tidyall(tracks, database);
+	}
+	rr = tracking_done(tracks);
+	RET_ENDUPDATE(r, rr);
+	return r;
+}
