@@ -1301,12 +1301,9 @@ static retvalue updates_startup(struct aptmethodrun *run, struct update_distribu
 			if( RET_WAS_ERROR(r) )
 				return r;
 		}
-		if( d->distribution->deb_override != NULL ||
-		    d->distribution->dsc_override != NULL ||
-		    d->distribution->udeb_override != NULL ) {
-			if( verbose >= 0 )
-				fprintf(stderr,"Warning: Override-Files of '%s' ignored as not yet supported while updating!\n",d->distribution->codename);
-		}
+		r = distribution_loadalloverrides(d->distribution);
+		if( RET_WAS_ERROR(r) )
+			return r;
 	}
 	return remote_startup(run);
 }
@@ -1336,7 +1333,7 @@ static retvalue calllisthook(struct update_target *ut, struct update_index_conne
 
 	/* distribution, component, architecture and pattern specific... */
 	newfilename = genlistsfilename(oldbasefilename, 5, "",
-			ut->target->codename,
+			ut->target->distribution->codename,
 			atoms_components[ut->target->component_atom],
 			atoms_architectures[ut->target->architecture_atom],
 			origin->pattern->name, ENDOFARGUMENTS);
@@ -1359,7 +1356,7 @@ static retvalue calllisthook(struct update_target *ut, struct update_index_conne
 		setenv("REPREPRO_DIST_DIR", global.distdir, true);
 		setenv("REPREPRO_LOG_DIR", global.logdir, true);
 		setenv("REPREPRO_FILTER_CODENAME",
-				ut->target->codename, true);
+				ut->target->distribution->codename, true);
 		setenv("REPREPRO_FILTER_PACKAGETYPE",
 				atoms_architectures[ut->target->packagetype_atom],
 				true);
@@ -1417,7 +1414,7 @@ static retvalue callshellhook(struct update_target *ut, struct update_index_conn
 
 	/* distribution, component, architecture and pattern specific... */
 	newfilename = genlistsfilename(oldbasefilename, 5, "",
-			ut->target->codename,
+			ut->target->distribution->codename,
 			atoms_components[ut->target->component_atom],
 			atoms_architectures[ut->target->architecture_atom],
 			origin->pattern->name, ENDOFARGUMENTS);
@@ -1468,7 +1465,7 @@ static retvalue callshellhook(struct update_target *ut, struct update_index_conn
 		setenv("REPREPRO_DIST_DIR", global.distdir, true);
 		setenv("REPREPRO_LOG_DIR", global.logdir, true);
 		setenv("REPREPRO_FILTER_CODENAME",
-				ut->target->codename, true);
+				ut->target->distribution->codename, true);
 		setenv("REPREPRO_FILTER_PACKAGETYPE",
 				atoms_architectures[ut->target->packagetype_atom],
 				true);
